@@ -1,4 +1,13 @@
+use strict;
 package Net::API::RPX;
+BEGIN {
+  $Net::API::RPX::AUTHORITY = 'cpan:KONOBI';
+}
+{
+  $Net::API::RPX::VERSION = '0.03';
+}
+
+# ABSTRACT: Perl interface to Janrain's RPX service
 
 use Moose;
 use LWP::UserAgent;
@@ -8,18 +17,6 @@ use Net::API::RPX::Exception::Usage;
 use Net::API::RPX::Exception::Network;
 use Net::API::RPX::Exception::Service;
 
-=head1 NAME
-
-Net::API::RPX - Perl interface to Janrain's RPX service
-
-=head1 VERSION
-
-Version 0.02
-
-=cut
-
-our $VERSION = '0.02';
-
 has api_key => (
     is       => 'rw',
     isa      => 'Str',
@@ -52,57 +49,9 @@ has _agent_string => (
     isa      => 'Str',
     required => 1,
     lazy     => 1,
-    default  => sub { "net-api-rpx-perl/$VERSION" },
+    default  => sub { 'net-api-rpx-perl/' . $Net::API::RPX::VERSION },
 );
 
-=head1 SYNOPSIS
-
-    use Net::API::RPX;
-
-    my $rpx = Net::API::RPX->new({ api_key => '<your_api_key_here>' });
-
-    $rpx->auth_info({ token => $token });
-
-=head1 DESCRIPTION
-
-This module is a simple wrapper around Janrain's RPX service. RPX provides a single method for
-dealing with third-party authentication.
-
-See L<http://www.rpxnow.com> for more details.
-
-For specific information regarding the RPX API and method arguments, please refer to
-L<https://rpxnow.com/docs>.
-
-=head1 ATTRIBUTES
-
-This is a Moose based module, this classes attribtues are as so:
-
-=head2 api_key
-
-This is the api_key provided by Janrain to interface with RPX. You will need to signup to RPX
-to get one of these.
-
-=head2 base_url
-
-This is the base URL that is used to make API calls against. It defaults to the RPX v2 API.
-
-=head2 ua
-
-This is a LWP::UserAgent object. You may override it if you require more fine grain control
-over remote queries.
-
-=head1 METHODS
-
-=head2 auth_info
-
-    my $user_data = $rpx->auth_info({ token => $params{token} });
-
-Upon redirection back from RPX, you will be supplied a token to use for verification. Call
-auth_info to verify the authenticity of the token and gain user details.
-
-'token' argument is required, 'extended' argument is optional.
-
-=cut
 
 sub auth_info {
     my ( $self, $opts ) = @_;
@@ -117,15 +66,6 @@ sub auth_info {
     return $self->_fetch( 'auth_info', $opts );
 }
 
-=head2 map
-
-    $rpx->map({ identifier => 'yet.another.open.id', primary_key => 12 });
-
-This method allows you to map more than one 'identifier' to a user.
-
-'identifier' argument is required, 'primary_key' argument is required, 'overwrite' is optional.
-
-=cut
 
 sub map {
     my ( $self, $opts ) = @_;
@@ -151,15 +91,6 @@ sub map {
     return $self->_fetch( 'map', $opts );
 }
 
-=head2 unmap
-
-    $rpx->unmap({ identifier => 'yet.another.open.id', primary_key => 12 });
-
-This is the inverse of 'map'.
-
-'identifier' argument is required, 'primary_key' argument is required.
-
-=cut
 
 sub unmap {
     my ( $self, $opts ) = @_;
@@ -186,15 +117,6 @@ sub unmap {
     return $self->_fetch( 'unmap', $opts );
 }
 
-=head2 mappings
-
-    my $data = $rpx->mappings({ primary_key => 12 });
-
-This method returns information about the identifiers associated with a user.
-
-'primary_key' argument is required.
-
-=cut
 
 sub mappings {
     my ( $self, $opts ) = @_;
@@ -264,6 +186,90 @@ sub _fetch {
     return $data;
 }
 
+1;    # End of Net::API::RPX
+
+__END__
+=pod
+
+=head1 NAME
+
+Net::API::RPX - Perl interface to Janrain's RPX service
+
+=head1 VERSION
+
+version 0.03
+
+=head1 SYNOPSIS
+
+    use Net::API::RPX;
+
+    my $rpx = Net::API::RPX->new({ api_key => '<your_api_key_here>' });
+
+    $rpx->auth_info({ token => $token });
+
+=head1 DESCRIPTION
+
+This module is a simple wrapper around Janrain's RPX service. RPX provides a single method for
+dealing with third-party authentication.
+
+See L<http://www.rpxnow.com> for more details.
+
+For specific information regarding the RPX API and method arguments, please refer to
+L<https://rpxnow.com/docs>.
+
+=head1 ATTRIBUTES
+
+This is a Moose based module, this classes attribtues are as so:
+
+=head2 api_key
+
+This is the api_key provided by Janrain to interface with RPX. You will need to signup to RPX
+to get one of these.
+
+=head2 base_url
+
+This is the base URL that is used to make API calls against. It defaults to the RPX v2 API.
+
+=head2 ua
+
+This is a LWP::UserAgent object. You may override it if you require more fine grain control
+over remote queries.
+
+=head1 METHODS
+
+=head2 auth_info
+
+    my $user_data = $rpx->auth_info({ token => $params{token} });
+
+Upon redirection back from RPX, you will be supplied a token to use for verification. Call
+auth_info to verify the authenticity of the token and gain user details.
+
+'token' argument is required, 'extended' argument is optional.
+
+=head2 map
+
+    $rpx->map({ identifier => 'yet.another.open.id', primary_key => 12 });
+
+This method allows you to map more than one 'identifier' to a user.
+
+'identifier' argument is required, 'primary_key' argument is required, 'overwrite' is optional.
+
+=head2 unmap
+
+    $rpx->unmap({ identifier => 'yet.another.open.id', primary_key => 12 });
+
+This is the inverse of 'map'.
+
+'identifier' argument is required, 'primary_key' argument is required.
+
+=head2 mappings
+
+    my $data = $rpx->mappings({ primary_key => 12 });
+
+This method returns information about the identifiers associated with a user.
+
+'primary_key' argument is required.
+
 =head1 TEST COVERAGE
 
 This distribution is heavily unit and system tested for compatability with
@@ -278,11 +284,6 @@ how to supply these.
  Total                         100.0  100.0    n/a  100.0  100.0  100.0  100.0
  ---------------------------- ------ ------ ------ ------ ------ ------ ------
 
-
-=head1 AUTHOR
-
-Scott McWhirter, C<< <konobi at cpan.org> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-net-api-rpx at rt.cpan.org>, or through
@@ -295,7 +296,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Net::API::RPX
 
-
 You can also look for information at:
 
 =over 4
@@ -322,12 +322,27 @@ L<http://search.cpan.org/dist/Net-API-RPX>
 
 L<http://www.janrain.com/>, L<http://www.rpxnow.com/>
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHORS
 
-Copyright 2009 Cloudtone Studios, all rights reserved.
+=over 4
 
-This program is released under the following license: BSD. Please see the LICENSE file included in this distribution for details.
+=item *
+
+Scott McWhirter <konobi@cpan.org>
+
+=item *
+
+Kent Fredric <kentnl@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Cloudtone Studios.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
 
 =cut
 
-1;    # End of Net::API::RPX
