@@ -1,15 +1,15 @@
-package Net::API::RPX::Exception::Usage;
-
-# $Id:$
 use strict;
+package Net::API::RPX::Exception::Usage;
+BEGIN {
+  $Net::API::RPX::Exception::Usage::AUTHORITY = 'cpan:KONOBI';
+}
+{
+  $Net::API::RPX::Exception::Usage::VERSION = '0.03';
+}
+
+# ABSTRACT: For when the interface is used wrongly
 use warnings;
 
-=head1 NAME
-
-Net::API::RPX::Exception::Usage - For when the interface is used wrongly.
-
-=cut
-
 use Moose;
 use namespace::autoclean;
 
@@ -43,3 +43,39 @@ around message => sub {
 __PACKAGE__->_immutable;
 1;
 
+
+__END__
+=pod
+
+=head1 NAME
+
+Net::API::RPX::Exception::Usage - For when the interface is used wrongly
+
+=head1 VERSION
+
+version 0.03
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Scott McWhirter <konobi@cpan.org>
+
+=item *
+
+Kent Fredric <kentnl@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Cloudtone Studios.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
+
+=cut
+
